/*
 * Copyright (c) ROSA Laboratory 2011
 * License: GPLv3
 *
 * Authors:
 *  Julia Mineeva <julia.mineeva@osinit.ru>
 *  Evgeniy Augin <evgeniy.augin@osinit.ru>
 *  Ivan Kulkov   <ivan.kulkov@osinit.ru>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 3,
 *   or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// local
#include "galleryarea.h"

#include "timeframelistview.h"
#include "timeframedirmodel.h"
#include "timeframedirlister.h"

// QT
#include <QListView>
#include <QGraphicsLinearLayout>
#include <QStringList>

// KDE
#include <kfilepreviewgenerator.h>
#include <kdirlister.h>

// KIO
#include <kio/previewjob.h>

QGalleryArea::QGalleryArea(QGraphicsItem *parent, Qt::WindowFlags wFlags)
    : QActivityEventsArea(parent, wFlags)
    , m_view(0)
{
    setupWidgets();
    m_view = 0;
    m_model = 0;
    m_previewGenerator = 0;
};

QGalleryArea::~QGalleryArea()
{
    if (m_view)
    {
        delete m_view;
        m_view =0;
    }

    if (m_model)
    {
        delete m_model;
        m_model =0;
    }
    if (m_previewGenerator)
    {
        delete m_previewGenerator;
        m_previewGenerator =0;
    }
}

void QGalleryArea::setupWidgets()
{
    // create list view
    m_view = new TimeFrameListView();

    // create and set model
    TimeFrameDirModel* m_model = m_nepomukSource->getDirModel();
    m_model->setJobTransfersVisible(true);

    m_view->nativeWidget()->setModel(m_model);

    // hide and delete animation widget
    m_animationLabel->hide();
    m_layout->removeItem(m_animationLabel);
    m_layout->addItem(m_view);

    // set preview generator for item's thumbnails creating

    KFilePreviewGenerator* m_previewGenerator = new KFilePreviewGenerator(m_view->nativeWidget());
    m_previewGenerator->setPreviewShown(true);
    QStringList list = KIO::PreviewJob::availablePlugins();
    m_previewGenerator->setEnabledPlugins(list);

};

void QGalleryArea::stopAnimation()
{
};

void QGalleryArea::startAnimation()
{
};

void QGalleryArea::showNewEvent(ActivityEvent* event)
{
//    qDebug("NEW EVENT");
};
