/*
 * Copyright (c) ROSA Laboratory 2011
 * License: GPLv3
 *
 * Authors:
 *   Julia Mineeva <julia.mineeva@osinit.ru>
 *   Evgeniy Augin <evgeniy.augin@osinit.ru>
 *   Ivan Kulkov   <ivan.kulkov@osinit.ru>
 *
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 3,
 *   or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef TIMEFRAMEITEMDELEGATE_H
#define TIMEFRAMEITEMDELEGATE_H

// KDE
#include <QtGui/QAbstractItemDelegate>
#include <QtGui/QTextOption>
#include <kio/global.h>

class QAbstractItemModel;
class QAbstractItemView;
class QHelpEvent;
class QModelIndex;
class QPainter;


class KIO_EXPORT TimeFrameItemDelegate : public QAbstractItemDelegate
{
    Q_OBJECT

    Q_PROPERTY(InformationList information READ showInformation WRITE setShowInformation)
    Q_PROPERTY(QColor shadowColor READ shadowColor WRITE setShadowColor)
    Q_PROPERTY(QPointF shadowOffset READ shadowOffset WRITE setShadowOffset)
    Q_PROPERTY(qreal shadowBlur READ shadowBlur WRITE setShadowBlur)
    Q_PROPERTY(QSize maximumSize READ maximumSize WRITE setMaximumSize)
    Q_PROPERTY(bool showToolTipWhenElided READ showToolTipWhenElided WRITE setShowToolTipWhenElided)
    Q_ENUMS(Information)

public:
    enum Information {
        NoInformation,     ///< No additional information will be shown for items.
        Size,              ///< The file size for files, and the number of items for folders.
        Permissions,       ///< A UNIX permissions string, e.g. -rwxr-xr-x.
        OctalPermissions,  ///< The permissions as an octal value, e.g. 0644.
        Owner,             ///< The user name of the file owner, e.g. root
        OwnerAndGroup,     ///< The user and group that owns the file, e.g. root:root
        CreationTime,      ///< The date and time the file/folder was created.
        ModificationTime,  ///< The date and time the file/folder was last modified.
        AccessTime,        ///< The date and time the file/folder was last accessed.
        MimeType,          ///< The mime type for the item, e.g. text/html.
        FriendlyMimeType,   ///< The descriptive name for the mime type, e.g. HTML Document.
        LinkDest,
        LocalPathOrUrl,
        Comment
    };

    typedef QList<Information> InformationList;
    explicit TimeFrameItemDelegate(QObject *parent = 0);
    virtual ~TimeFrameItemDelegate();
    virtual QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const;
    virtual void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
    virtual QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const;
    virtual bool editorEvent(QEvent *event, QAbstractItemModel *model, const QStyleOptionViewItem & option, const QModelIndex &index);
    virtual void setEditorData(QWidget *editor, const QModelIndex &index) const;
    virtual void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const;
    virtual void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option,const QModelIndex &index) const;
    void setShowInformation(const InformationList &list);
    void setShowInformation(Information information);
    InformationList showInformation() const;
    void setShadowColor(const QColor &color);
    QColor shadowColor() const;
    void setShadowOffset(const QPointF &offset);
    QPointF shadowOffset() const;
    void setShadowBlur(qreal radius);
    qreal shadowBlur() const;
    void setMaximumSize(const QSize &size);
    QSize maximumSize() const;
    void setShowToolTipWhenElided(bool showToolTip);
    bool showToolTipWhenElided() const;

    QRect iconRect(const QStyleOptionViewItem &option, const QModelIndex &index) const;

    void setWrapMode(QTextOption::WrapMode wrapMode);
    QTextOption::WrapMode wrapMode() const;

    void setJobTransfersVisible(bool jobTransfersVisible);
    bool jobTransfersVisible() const;

    virtual bool eventFilter(QObject *object, QEvent *event);


public Q_SLOTS:
    bool helpEvent(QHelpEvent * event, QAbstractItemView *view, const QStyleOptionViewItem &option, const QModelIndex &index);
    QRegion shape(const QStyleOptionViewItem &option, const QModelIndex &index);

private:
    class Private;
    Private * const d; /// @internal
    Q_DISABLE_COPY(TimeFrameItemDelegate)
};

#endif // TIMEFRAMEITEMDELEGATE_H
